/*!
* Module dependencies.
*/

var mongoose = require('mongoose');
var config = require('../../config/env/development');
var async = require('async');
var utils = require('../../utils');
var fs = require('fs');
var path = require('path');

var Level = mongoose.model('Level');

exports.read = function (req, res) {
    var query = {};
    Level.find(query).sort({ level: 1 }).exec(function (err, levels) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to read levels data', JSON.stringify(err.errors));
        } else {
            return utils.sendSuccessResponse(res, 200, levels);
        }
    })
}

exports.detail = function (req, res) {
    var levelId = req.params.levelId;
    Level.findOne({ _id: levelId }).exec(function (err, level) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to read level data', JSON.stringify(err.errors));
        } else {
            return utils.sendSuccessResponse(res, 200, level);
        }
    })
}

exports.create = function (req, res) {
    var level = new Level(req.body);
    level.save(function (err, savedLevel) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to create a new level', JSON.stringify(err.errors));
        } else {
            return utils.sendSuccessResponse(res, 200, savedLevel);
        }
    });
}

exports.update = function (req, res) {
    var levelId = req.params.levelId;
    var updateParams = req.body;
    Level.findOneAndUpdate({ _id: levelId }, { $set: updateParams }, { new: true, upsert: true }).exec(function (err, updatedLevel) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to update level', JSON.stringify(err.errors));
        } else {
            return utils.sendSuccessResponse(res, 200, updatedLevel);
        }
    })
}

exports.delete = function (req, res) {
    var levelId = req.params.levelId;
    Level.remove({ _id: levelId }).exec(function (err, data) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to delete level entry', JSON.stringify(err.errors));
        } else {
            if (data['n'] == 1) {
                return utils.sendSuccessResponse(res, 200,
                    {
                        message: "Deleted level",
                        success: true
                    }
                );
            } else {
                return utils.sendSuccessResponse(res, 200,
                    {
                        message: "No level found to delete",
                        success: false
                    }
                );
            }
        }
    })
}
