/*!
* Module dependencies.
*/

var mongoose = require('mongoose');
var config = require('../../config/env/development');
var async = require('async');
var utils = require('../../utils');
var fs = require('fs');
var path = require('path');

var Task = mongoose.model('Task');

exports.read = function (req, res) {
    var query = {};
    if (req.query.enabled) {
        query['enabled'] = req.query.enabled;
    }
    var language = req.query.language;
    Task.find(query).sort({ id: 1 }).exec(async function (err, tasks) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to read tasks data', JSON.stringify(err.errors));
        } else {
            if(language){
                let response=[], data;
                 for (let index = 0; index < tasks.length; index++) {
                     data=await transalationService(tasks[index],language);
                     response.push(data.task)
                     if (data.update)
                       udpate(tasks[index]._id, data.task)
                 }
                 return utils.sendSuccessResponse(res, 200, response);
             }else{
                 return utils.sendSuccessResponse(res, 200, tasks);
             }
        }
    })
}

exports.detail = function (req, res) {
    var taskId = req.params.taskId;
    var language = req.query.language;
    var data;
    Task.findOne({ _id: taskId }).exec(async function (err, task) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to read task data', JSON.stringify(err.errors));
        } else {
            if(language){
                data=await transalationService(task,language);
                if (data.update)
                   udpate(taskId, data.task)
            }
            return utils.sendSuccessResponse(res, 200,language? data.task:task);
        }
    })
}

exports.create = function (req, res) {
    if (req.file) {
        req.body.imageUrl = config.assets.url + '/' + req.file.filename;
    }
    var task = new Task(req.body);
    task.save(function (err, savedTask) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to create a new task', JSON.stringify(err.errors));
        } else {
            return utils.sendSuccessResponse(res, 200, savedTask);
        }
    });
}

exports.update = function (req, res) {
    var taskId = req.params.taskId;
    if (req.file) {
        req.body.imageUrl = config.assets.url + '/' + req.file.filename;
    }
    var updateParams = req.body;
    updateParams.translation={name:{},tutorials:{}};
    Task.findOneAndUpdate({ _id: taskId }, { $set: updateParams }, { new: true, upsert: true }).exec(function (err, updatedTask) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to update task', JSON.stringify(err.errors));
        } else {
            return utils.sendSuccessResponse(res, 200, updatedTask);
        }
    })
}

exports.delete = function (req, res) {
    var taskId = req.params.taskId;
    Task.remove({ _id: taskId }).exec(function (err, data) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to delete task entry', JSON.stringify(err.errors));
        } else {
            if (data['result']['n'] == 1) {
                return utils.sendSuccessResponse(res, 200,
                    {
                        message: "Deleted task",
                        success: true
                    }
                );
            } else {
                return utils.sendSuccessResponse(res, 200,
                    {
                        message: "No task found to delete",
                        success: false
                    }
                );
            }
        }
    })
}
function udpate(id,data){
    Task.findOneAndUpdate({ _id: id }, { $set: data }, { new: false, upsert: false }).exec(function (err, response) {
        if (err) {
            console.log(err);
        }
    })
}
async function transalationService(task,language){
    var response={
        translation:{
            name:{[language]:{}},
            tutorials:{[language]:[]}
    }};
   
    var update=false;
    if(!task.translation){
        task["translation"]=response.translation;
    }

    if (!task || !task.translation || !task.translation.name || !task.translation.name[language] || !task.translation.name[language].length) {
      update = true;
      response.translation.name[language] = task.name? await utils.translateText(task.name, language):"";
      task["translation"]["name"] =(task["translation"]&&task["translation"]["name"])? {
        ...task["translation"]["name"],
        ...response.translation.name
      }:response.translation.name
    }
   
    if (!task.translation || !task.translation.tutorials || !task.translation.tutorials[language] || !task.translation.tutorials[language].length) {
      update = true;
      for (let index = 0; index < task.tutorials.length; index++) {
        response.translation.tutorials[language][index]={name: task.tutorials[index]["name"]?await utils.translateText(task.tutorials[index]["name"], language):"",text: task.tutorials[index]["text"]?await utils.translateText(task.tutorials[index]["text"], language):""};
    }
      
      task["translation"]["tutorials"] =(task["translation"] && task["translation"]["tutorials"])? {
        ...task["translation"]["tutorials"],
        ...response.translation.tutorials
      }:response.translation.tutorials
    }

    return {task,update};
}