/*!
* Module dependencies.
*/

var mongoose = require('mongoose');
var config = require('../../config/env/development');
var async = require('async');
var utils = require('../../utils');
var fs = require('fs');
var path = require('path');

var Tutorial = mongoose.model('Tutorial');

exports.read = function (req, res) {
    var query = {};
    var language = req.query.language;
    Tutorial.find(query).sort({ id: 1 }).exec(async function (err, tutorials) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to read tutorials data', JSON.stringify(err.errors));
        } else {
            if(language){
                let response=[], data;
                 for (let index = 0; index < tutorials.length; index++) {
                     data=await transalationService(tutorials[index],language);
                     response.push(data.tutorial)
                     if (data.update)
                       udpate(tutorials[index]._id, data.tutorial)
                 }
                 return utils.sendSuccessResponse(res, 200, response);
             }else{
                 return utils.sendSuccessResponse(res, 200, tutorials);
             }
        }
    })
}

exports.detail = function (req, res) {
    var tutorialId = req.params.tutorialId;
    var language = req.query.language;
    var data;
    Tutorial.findOne({ _id: tutorialId }).exec(async function (err, tutorial) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to read tutorial data', JSON.stringify(err.errors));
        } else {
            if(language){
                data=await transalationService(tutorial,language);
                if (data.update)
                   udpate(tutorialId, data.tutorial)
            }
            return utils.sendSuccessResponse(res, 200,language? data.tutorial:tutorial);
        }
    })
}

exports.create = function (req, res) {
    if (req.file) {
        req.body.imageUrl = config.assets.url + '/' + req.file.filename;
    }
    var tutorial = new Tutorial(req.body);
    tutorial.save(function (err, savedTutorial) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to create a new tutorial', JSON.stringify(err.errors));
        } else {
            return utils.sendSuccessResponse(res, 200, savedTutorial);
        }
    });
}

exports.update = function (req, res) {
    var tutorialId = req.params.tutorialId;
    if (req.file) {
        req.body.imageUrl = config.assets.url + '/' + req.file.filename;
    }
    var updateParams = req.body;
    var unsetParams = {};
    if (req.body.pointerType == 'hand') {
        unsetParams['arrow'] = 1;
    } else if (req.body.pointerType == 'arrow') {
        unsetParams['hand'] = 1;
    }
    updateParams.translation={text:{}};
    Tutorial.findOneAndUpdate({ _id: tutorialId }, { $set: updateParams, $unset: unsetParams }, { new: true, upsert: true }).exec(function (err, updatedTutorial) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to update tutorial', JSON.stringify(err.errors));
        } else {
            return utils.sendSuccessResponse(res, 200, updatedTutorial);
        }
    })
}

exports.delete = function (req, res) {
    var tutorialId = req.params.tutorialId;
    Tutorial.remove({ _id: tutorialId }).exec(function (err, data) {
        if (err) {
            return utils.sendFailureResponse(res, 500, 1011, err.message, 'Failed to delete tutorial entry', JSON.stringify(err.errors));
        } else {
            if (data['result']['n'] == 1) {
                return utils.sendSuccessResponse(res, 200,
                    {
                        message: "Deleted tutorial",
                        success: true
                    }
                );
            } else {
                return utils.sendSuccessResponse(res, 200,
                    {
                        message: "No tutorial found to delete",
                        success: false
                    }
                );
            }
        }
    })
}

function udpate(id,data){
    Tutorial.findOneAndUpdate({ _id: id }, { $set: data }, { new: false, upsert: false }).exec(function (err, updatedtutorial) {
        if (err) {
            console.log(err);
        }
    })
}
async function transalationService(tutorial,language){
    var response={
        translation:{
            text:{[language]:{}},
            
    }};
    if(!tutorial.translation){
        tutorial["translation"] =response.translation 
    }
    var update=false;
    if (!tutorial || !tutorial.translation || !tutorial.translation.text || !tutorial.translation.text[language] || !tutorial.translation.text[language].length) {
      update = true;
      response.translation.text[language] = tutorial.text? await utils.translateText(tutorial.text, language):"";
      tutorial["translation"]["text"] =(tutorial["translation"]&&tutorial["translation"]["text"])? {
        ...tutorial["translation"]["text"],
        ...response.translation.text
      }:response.translation.text
    }
    return {tutorial,update};
}