/*!
* Module dependencies
*/

var mongoose = require('mongoose');
var Schema = mongoose.Schema;

var UserBuildingSchema = new Schema({
    buildingId: {
        type: Number
    },
    name: {
        type: String
    },
    level: {
        type: Number
    },
    type: {
        type: String
    },
    subType: {
        type: Number
    },
    state: {
        type: Number,
        enum: [0, 1, 2, 3, 4]         // kBuildingBeingPlaced, kBuildingBeingBuilt, kBuildgingBeingBuiltAndMoved, kBuildingPlaced,kBuildingBeingMoved
    },
    image: {
        type: String
    },
    appeal: {
        type: Number
    },
    addedAppeal: {
        type: Number
    },
    usageFee: {
        type: Number
    },
    currentCoins: {
        type: Number
    },
    maxCoins: {
        type: Number
    },
    position: {
        xPosition: {
            type: Number
        },
        yPosition: {
            type: Number
        }
    },
    zOrder: {
        type: Number
    },
    rotated: {
        type: Boolean
    },
    stored: {
        type: Boolean
    },
    blocked: {
        type: Boolean
    },
    floor: {
        type: Number
    },
    createdTimestamp: {
        type: Date
    },
    constructionTimestamp: {
        type: Date
    },
    upgradeTimestamp: {
        type: Date
    },
    dialogues: [String],
    // shoppersQueue: [BuildingShoppersQueueSchema],
    nearbyBuildings: [String]
})


var BuildingShoppersQueueSchema = new Schema({
    shopperId: {
        type: Number
    },
    stepsToBuilding: {
        type: Number
    },
})

var UserShopperSchema = new Schema({
    shopperId: {
        type: Number
    },
    name: {
        type: String,
    },
    type: {
        type: Number
    },
    coins: {
        type: Number
    },
    maxCoins: {
        type: Number
    },
    position: {
        xPosition: {
            type: Number
        },
        yPosition: {
            type: Number
        }
    },
    animationState: {
        type: Number
    },
    floor: {
        type: Number
    },
    animationFile: {
        type: String
    },
    // tasks: [ShopperTaskSchema]
    tasks: [{
        taskType: {
            type: Number
        },
        taskStatus: {
            type: Number
        },
        buildingId: {
            type: Number
        },
        status: {
            type: String,
            enum: ['pending', 'completed', 'collected']
        },
        subTasks: [{
            subTaskType: {
                type: Number
            },
            subTaskStatus: {
                type: Number
            },
            buildingType: {
                type: Number
            },
            timeForSubTask: {
                type: Number
            },
        }]
    }]
})

// var ShopperTaskSchema = new Schema({
//     taskType: {
//         type: Number,
//     },
//     taskStatus: {
//         type: Number,
//     },
//     buildingId: {
//         type: Number,
//     },
//     status: {
//         type: String,
//         enum: ['pending', 'completed', 'collected']
//     },
//     subTasks: [ShopperSubTaskSchema]
// })

// var ShopperSubTaskSchema = new Schema({
//     subTaskType: {
//         type: Number,
//     },
//     subTaskStatus: {
//         type: Number,
//     },
//     buildingType: {
//         type: Number,
//     },
//     timeForSubTask: {
//         type: Number
//     }
// })

var UserTaskSchema = new Schema({
    id: {
        type: Number,
    },
    status: {
        type: String,
        enum: ['pending', 'completed', 'collected']
    }
})

var UserProfileSchema = new Schema({
    fbId: {
        type: String
    },
    name: {
        type: String
    },
    googleId: {
        type: String
    },
    deviceId: {
        type: String
    },
    pushToken: {
        type: String
    },
    device: {
        type: String,
        enum: ['android', 'iOS']
    },
    coins: {
        type: Number,
    },
    maxCoins: {
        type: Number
    },
    diamonds: {
        type: Number
    },
    xp: {
        type: Number,
    },
    level: {
        type: Number
    },
    landSize: {
        width: {
            type: Number
        },
        height: {
            type: Number
        }
    },
    maxBuilders: {
        Number
    },
    buildingIdCount: {
        Number
    },
    characterIdCount: {
        Number
    },
    firstSetTutorial: {
        Boolean
    },
    shoppers: [UserShopperSchema],
    buildings: [UserBuildingSchema],
    tasks: [UserTaskSchema],
    completedTutorials: [Number],
    boughtCharacter: [Number],

});


/**
* Register
*/

mongoose.model('UserProfile', UserProfileSchema);
